chicken_turtle_util.dict
========================

.. automodule:: chicken_turtle_util.dict

.. autosummary::
   :nosignatures:

   assign
   DefaultDict
   invert
   pretty_print_head

.. autofunction:: assign
.. autoclass:: DefaultDict
.. autofunction:: invert
.. autofunction:: pretty_print_head
